# Changelog for Django Glue

## 0.3.0

#### Features
- You can now glue methods.


#### Changes
- Clean up internal functions to more efficient.

## 0.2.5

#### Bugs
- Fixed issue with overwriting unique_names

## 0.2.4

#### Bugs
- Fixed a session data saving issues to make sure when using new keep life it saves all session data.

## 0.2.3

#### Features
- Can handle multiple tabs or webpages open at the same time.

## 0.2.2

#### Changes
- Removed css files for old messaging system.
- Added glue_init_core to allow people to include their own alpine and axios files.

## 0.2.1

#### Changes
- Updated middleware to use settings glue name.

#### Bugs
- Fixed context processor key error.
- Fixed templates and static package error.
